@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "abcdfhlmnoprstuvw",
+  0: "abcdefhilmnoprstuvw",
   1: "cfl",
   2: "abcdflmnoprstvw",
   3: "acdfln",
@@ -9,7 +9,7 @@ var indexSectionsWithContent =
   6: "a",
   7: "a",
   8: "ah",
-  9: "a"
+  9: "abdefimopsuv"
 };
 
 var indexSectionNames =
